@@ -10,7 +10,7 @@ from tqdm import tqdm
 
 from mootdx.consts import MARKET_SH
 from mootdx.consts import MARKET_SZ
-from mootdx.logger import log
+from mootdx.logger import logger
 from mootdx.utils.adjust import to_adjust
 
 
@@ -82,7 +82,7 @@ def gpcw(filepath):
         info_data = cw_file.read(calcsize('<264f'))
         cw_info = unpack('<264f', info_data)
 
-        log.debug(f'{code}, {cw_info}')
+        logger.debug(f'{code}, {cw_info}')
         return code, cw_info
 
 
@@ -99,8 +99,8 @@ def md5sum(downfile):
         md5_l.update(Path(downfile).read_bytes())
         return md5_l.hexdigest()
     except (IOError, FileNotFoundError) as e:
-        log.error(f'无法读取文件: {downfile}')
-        log.debug(e)
+        logger.error(f'无法读取文件: {downfile}')
+        logger.debug(e)
         return None
 
 
@@ -146,6 +146,14 @@ def to_data(v, **kwargs):
         from mootdx.utils.adjust import fq_factor
         result = to_adjust(result, symbol=symbol, adjust=adjust)
 
+    if "datetime" in result.columns:
+        result.index = pd.to_datetime(result.datetime)
+    elif "date" in result.columns:
+        result.index = pd.to_datetime(result.date)
+
+    if "vol" in result.columns:
+        result['volume'] = result.vol
+
     return result
 
 
@@ -166,6 +174,10 @@ def to_file(df, filename=None):
     # 目录不存在创建目录
     Path(path_name).is_dir() or Path(path_name).mkdir(parents=True)
 
+    # methods = {'to_json': ['.json']}
+    # method = [k for k, v in methods if extension in v][0]
+    # getattr(pd, method)(filename)
+
     if extension == '.csv':
         return df.to_csv(filename, encoding='utf-8', index=False)
 
@@ -247,7 +259,7 @@ def block_new(tdxdir=None, name: str = None, symbol: list = None):
 
     # 判断目录是否存在
     if not Path(vipdoc).is_dir():
-        log.error(f'自定义板块目录错误: {vipdoc}')
+        logger.error(f'自定义板块目录错误: {vipdoc}')
         return False
 
     block_file = Path(vipdoc) / 'blocknew.cfg'
@@ -264,7 +276,7 @@ def block_new(tdxdir=None, name: str = None, symbol: list = None):
         names = [v for i, v in enumerate(names) if i % 2 == 0]
 
         if name in names:
-            log.error('自定义板块名称重复.')
+            logger.error('自定义板块名称重复.')
             raise Exception('自定义板块名称重复.')
 
     # 写 blk 文件
